[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible fedora rpms: mock needs a write resultdir

Holger Levsen holger at moszumanska.debian.org
Fri Dec 11 20:06:45 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 2ef59db319a5925d29daea6927194aebb8a38426
Author: Holger Levsen <holger at layer-acht.org>
Date:   Fri Dec 11 21:06:28 2015 +0100

    reproducible fedora rpms: mock needs a write resultdir
---
 bin/reproducible_setup_mock.sh | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/bin/reproducible_setup_mock.sh b/bin/reproducible_setup_mock.sh
index 6559667..efb2c47 100755
--- a/bin/reproducible_setup_mock.sh
+++ b/bin/reproducible_setup_mock.sh
@@ -4,7 +4,7 @@
 # released under the GPLv=2
 
 #
 # configures mock for a given distro and architecture
 #
 
 DEBUG=false
@@ -12,16 +12,16 @@ DEBUG=false
 common_init "$@"
 
 if [ -z "$1" ] || [ -z "$2" ] ; then
-	echo "Need distro and architecture as params"
+	echo "Need release and architecture as params."
 	exit 1
 fi
-DISTRO=$1
-ARCHITECTURE=$2
+RELEASE=$1
+ARCH=$2
 
 echo "$(date -u) - showing setup."
 dpkg -l mock
 id
-echo "$(date -u) - starting to cleanly configure mock for ${DISTRO} on ${ARCHITECTURE}."
-mock -r ${DISTRO}-${ARCHITECTURE} --clean
-mock -r ${DISTRO}-${ARCHITECTURE} --init
-echo "$(date -u) - mock configured for ${DISTRO} on ${ARCHITECTURE}."
+echo "$(date -u) - starting to cleanly configure mock for $RELEASE on $ARCH."
+mock -r $RELEASE-$ARCH --resultdir=. --clean
+mock -r $RELEASE-$ARCH --resultdir=. --init
+echo "$(date -u) - mock configured for $RELEASE on $ARCH."
@@ -4,7 +4,7 @@
 
 #
-# configures mock for a given distro and architecture
+# configure mock for a given release and architecture
 #
 

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list